==> manydhcp2.5.2.tar.bz2: manydhcp/oborud/edit.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) include "../lang/".$lang."/".$lang.".php";
     else include "../lang/ru/ru.php";

  $title=$titlepage = $TEXT['oborud-title'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  if(empty($_POST['obor_id'])) {puterror($result2['skin'],$TEXT['error-oborud5']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_POST['obor_id'])>5) {puterror($result2['skin'],$TEXT['error-oborud6']); require_once "../utils/bottom_adm.php"; exit();}
  if(empty($_POST['oborud'])) {puterror($result2['skin'],$TEXT['error-oborud1']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_POST['oborud'])>200) {puterror($result2['skin'],$TEXT['error-oborud2']); require_once "../utils/bottom_adm.php"; exit();}

  if(isset($_POST['oborud'])) $oborud=trim($_POST['oborud']);
    else $oborud="";
     if(empty($oborud)) {puterror($result2['skin'],$TEXT['error-oborud3']); require_once "../utils/bottom_adm.php"; exit();}

  $_POST['oborud'] = rep($_POST['oborud']);
  $_POST['obor_id'] = rep($_POST['obor_id']);

  $query9 = "SELECT `oborud` FROM `tbl_oborud` WHERE `oborud`='".$_POST['oborud']."' ";
     $result9 = mysql_query($query9);
     if(!$result9) {puterror($result2['skin'],$TEXT['error-tbl12']); require_once "../utils/bottom_adm.php"; exit();}
       if(mysql_num_rows($result9)>0) {puterror($result2['skin'],$TEXT['error-double']); require_once "../utils/bottom_adm.php"; exit();}

  //*************************************
  //Информация для лога
  $query10 = "SELECT `oborud` FROM `tbl_oborud` WHERE `obor_id`='".$_POST['obor_id']."' ";
  $result10 = mysql_query($query10);
  if (!$result10) {puterror($result2['skin'],$TEXT['error-tbl12']); require_once "../utils/bottom_adm.php"; exit();}
      $result_dom = mysql_fetch_array($result10);

  $ip = $_SERVER['REMOTE_ADDR'];
  $doing = $TEXT['log-oborud3'];
  $what = $result_dom['oborud'].$TEXT['log-na'].$_POST['oborud'].$TEXT['log-id'].$_POST['obor_id'];
  $who = $result2['familiya']." ".$result2['name'];
  //*************************************

  $query = "UPDATE `tbl_oborud` SET `oborud` = '".$_POST['oborud']."' WHERE `obor_id`='".$_POST['obor_id']."' LIMIT 1";
  if(mysql_query($query))
  {
    $query2 = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
        if(mysql_query($query2))
           {
             echo "<html><head>
                   <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=index.php' />
                   </head></html>";
           } else {puterror($result2['skin'],$TEXT['error-log']); require_once "../utils/bottom_adm.php"; exit();}
  } else {puterror($result2['skin'],$TEXT['error-oborud8']); require_once "../utils/bottom_adm.php"; exit();}
require_once "../utils/bottom_adm.php";
?>

==> manydhcp2.8.2.tar.bz2: manydhcp/oborud/edit.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) {include "../lang/".$lang."/".$lang.".php";}
     else {include "../lang/ru/ru.php";}

  $title = $TEXT['oborud-title'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  if(empty($_POST['obor_id'])) {puterror($result2['skin'],$TEXT['error-oborud5']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_POST['obor_id'])>5) {puterror($result2['skin'],$TEXT['error-oborud6']); require_once "../utils/bottom_adm.php"; exit();}
  if(empty($_POST['oborud'])) {puterror($result2['skin'],$TEXT['error-oborud1']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_POST['oborud'])>200) {puterror($result2['skin'],$TEXT['error-oborud2']); require_once "../utils/bottom_adm.php"; exit();}

  if(isset($_POST['oborud'])) {$oborud=trim($_POST['oborud']);}
    else {$oborud="";}
     if(empty($oborud)) {puterror($result2['skin'],$TEXT['error-oborud3']); require_once "../utils/bottom_adm.php"; exit();}

  $_POST['oborud'] = rep($_POST['oborud']);
  $_POST['obor_id'] = rep($_POST['obor_id']);

  $query9 = "SELECT `oborud` FROM `tbl_oborud` WHERE `oborud`='".$_POST['oborud']."' ";
     $result9 = mysqli_query($dbcnx,$query9);
     if(!$result9) {puterror($result2['skin'],$TEXT['error-tbl12']); require_once "../utils/bottom_adm.php"; exit();}
       if(mysqli_num_rows($result9)>0) {puterror($result2['skin'],$TEXT['error-double']); require_once "../utils/bottom_adm.php"; exit();}

  //*************************************
  //Информация для лога
  $query10 = "SELECT `oborud` FROM `tbl_oborud` WHERE `obor_id`='".$_POST['obor_id']."' ";
  $result10 = mysqli_query($dbcnx,$query10);
  if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl12']); require_once "../utils/bottom_adm.php"; exit();}
    $result_dom = mysqli_fetch_array($result10,MYSQLI_ASSOC);

  $ip = $_SERVER['REMOTE_ADDR'];
  $doing = $TEXT['log-oborud3'];
  $what = $result_dom['oborud'].$TEXT['log-na'].$_POST['oborud'].$TEXT['log-id'].$_POST['obor_id'];
  $who = $result2['familiya']." ".$result2['name'];
  //*************************************

  $query = "UPDATE `tbl_oborud` SET `oborud` = '".$_POST['oborud']."' WHERE `obor_id`='".$_POST['obor_id']."' LIMIT 1";
  if(mysqli_query($dbcnx,$query))
  {
    $query2 = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
        if(mysqli_query($dbcnx,$query2))
           {
             echo "<html><head>
                   <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=index.php' />
                   </head></html>";
           } else {puterror($result2['skin'],$TEXT['error-log']); require_once "../utils/bottom_adm.php"; exit();}
  } else {puterror($result2['skin'],$TEXT['error-oborud8']); require_once "../utils/bottom_adm.php"; exit();}
require_once "../utils/bottom_adm.php";
?>
